BEARD_LP_MINSWAP_v1_ASSET_ID = (
    "e4214b7cce62ac6fbba385d164df48e157eae5863521b4b67ca71d862637dcfa955ec6eb059d12ecf3e038033fa856065e9eabe520b78cb1d337409c"
)
BEARD_LP_MINSWAP_v2_ASSET_ID = (
    "f5808c2c990d86da54bfc97d89cee6efa20cd8461616359478d96b4c52bd1e5a642e2141e8fb7ea6fa996960bc91db0b040c6d35013cf3efecac2dfc"
)
BOOK_LP_MINSWAP_v1_ASSET_ID = (
    "e4214b7cce62ac6fbba385d164df48e157eae5863521b4b67ca71d862ed309a7ecb6d0d5e00dca0bcc3924fdc0627a5fb631f1acc4deb898b14ee8bd"
)
BOOK_LP_MINSWAP_v2_ASSET_ID = (
    "f5808c2c990d86da54bfc97d89cee6efa20cd8461616359478d96b4cb68d128216cd07ee83667f1f5d2b65999b034161d88fada290eb5a9a6960c456"
)


LP_ASSETS = {
    BEARD_LP_MINSWAP_v1_ASSET_ID: "MINSWAP v1 $BEARD LP",
    BEARD_LP_MINSWAP_v2_ASSET_ID: "MINSWAP v2 $BEARD LP",
    BOOK_LP_MINSWAP_v1_ASSET_ID: "MINSWAP v1 $BOOK LP",
    BOOK_LP_MINSWAP_v2_ASSET_ID: "MINSWAP v2 $BOOK LP",
}
