ADA_HANDLE_POLICY_ID = "f0ff48bbb7bbe9d59a40f1ce90e9e9d0ff5002ec48f232b49ca0fb9a"
GUTENBERG_BIBLE_POLICY_ID = "477cec772adb1466b301fb8161f505aa66ed1ee8d69d3e7984256a43"
THE_ATTACK_ON_VITALIK_POLICY_ID = "58b2b7da117fdfe9c2afaf5da892eb44850c014a5a47243884e8aac4"
